@@ -9,7 +9,8 @@ from pymongo.errors import DocumentTooLarge, OperationFailure
 from inoopa_utils.custom_types.decision_makers import DecisionMaker
 from inoopa_utils.inoopa_logging import create_logger
 
-load_dotenv()
+
+load_dotenv(os.path.join(os.getcwd(), '.env'))
 
 
 class DbManagerMongo:
